@@ -8,7 +8,7 @@ use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.027';
+our $VERSION = '1.031';
 
 with qw(
     Locale::TextDomain::OO::Lexicon::Role::File
@@ -64,7 +64,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.027
+1.031
 
 =head1 DESCRIPTION
 
@@ -75,7 +75,7 @@ This module reads a gettext po file into the lexicon.
     use Locale::TextDomain::OO::Lexicon::File::PO;
     use Log::Any qw($log);
 
-    Locale::TextDomain::OO::Lexicon::File::PO
+    $logger = Locale::TextDomain::OO::Lexicon::File::PO
         ->new(
             # all parameters are optional
             decode_code => sub {
@@ -117,13 +117,17 @@ This module reads a gettext po file into the lexicon.
                 # and store that as "de-at::" lexicon with all messages now.
                 merge_lexicon => 'de::', 'de-at::' => 'de-at::',
 
+                # Copy a lexicon into another domain and/or category:
+                copy_lexicon => 'i-default::' => 'i-default:LC_MESSAGES:domain',
+
                 # Move a lexicon into another domain and/or category:
                 move_lexicon => 'i-default::' => 'i-default:LC_MESSAGES:domain',
 
                 # Delete a lexicon:
                 delete_lexicon => 'i-default::',
             ],
-        });
+        })
+        ->logger;
 
 =head1 SUBROUTINES/METHODS
 
@@ -144,7 +148,7 @@ to run the po file specific code.
 
 =head2 method logger
 
-Set the logger
+Set the logger and get back them
 
     $lexicon_file_po->logger(
         sub {
@@ -154,12 +158,15 @@ Set the logger
             return;
         },
     );
+    $logger = $lexicon_hash->logger;
 
 $arg_ref contains
 
     object => $lexicon_file_po, # the object itself
     type   => 'debug',
-    event  => 'lexicon,load',
+    event  => 'lexicon,load', # The logger will be copied to
+                              # Locale::TextDomain::OO::Singleton::Lexicon
+                              # so more events are possible.
 
 =head1 EXAMPLE
 
